#include "nvim/ex_docmd.h"
#include "nvim/ex_getln.h"
#include "nvim/insexpand.h"
#include "nvim/mapping.h"
#include "nvim/ops.h"
#include "nvim/option.h"
#include "nvim/optionstr.h"
#include "nvim/quickfix.h"
#include "nvim/runtime.h"
#include "nvim/tag.h"
#include "nvim/window.h"

static vimoption_T options[] = {
  [0]={
    .fullname="aleph",
    .shortname="al",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&options[0].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 224L },
  },
  [1]={
    .fullname="allowrevins",
    .shortname="ari",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_ari,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [2]={
    .fullname="ambiwidth",
    .shortname="ambw",
    .flags=0|kOptFlagRedrAll|kOptFlagUIOption,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_ambw,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_ambiwidth,
    .opt_expand_cb=expand_set_ambiwidth,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "single", .size = sizeof("single") - 1 } },
  },
  [3]={
    .fullname="arabic",
    .shortname="arab",
    .flags=0|kOptFlagCurswant,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_ARAB),
    .opt_did_set_cb=did_set_arabic,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [4]={
    .fullname="arabicshape",
    .shortname="arshape",
    .flags=0|kOptFlagRedrAll|kOptFlagUIOption,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_arshape,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [5]={
    .fullname="autochdir",
    .shortname="acd",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_acd,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_autochdir,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [6]={
    .fullname="autoindent",
    .shortname="ai",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_ai,
    .immutable=false,
    .indir=OPT_BUF(BV_AI),
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [7]={
    .fullname="autoread",
    .shortname="ar",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_ar,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_AR)),
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [8]={
    .fullname="autowrite",
    .shortname="aw",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_aw,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [9]={
    .fullname="autowriteall",
    .shortname="awa",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_awa,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [10]={
    .fullname="background",
    .shortname="bg",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_bg,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_background,
    .opt_expand_cb=expand_set_background,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "dark", .size = sizeof("dark") - 1 } },
  },
  [11]={
    .fullname="backspace",
    .shortname="bs",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_bs,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_backspace,
    .opt_expand_cb=expand_set_backspace,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "indent,eol,start", .size = sizeof("indent,eol,start") - 1 } },
  },
  [12]={
    .fullname="backup",
    .shortname="bk",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_bk,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [13]={
    .fullname="backupcopy",
    .shortname="bkc",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_bkc,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_BKC)),
    .opt_did_set_cb=did_set_backupcopy,
    .opt_expand_cb=expand_set_backupcopy,
#if defined(UNIX)
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "auto", .size = sizeof("auto") - 1 } },
#else
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "auto", .size = sizeof("auto") - 1 } },
#endif
  },
  [14]={
    .fullname="backupdir",
    .shortname="bdir",
    .flags=0|kOptFlagOneComma|kOptFlagExpand|kOptFlagNoDefExp|kOptFlagSecure|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_bdir,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [15]={
    .fullname="backupext",
    .shortname="bex",
    .flags=0|kOptFlagNFname,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_bex,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_backupext_or_patchmode,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "~", .size = sizeof("~") - 1 } },
  },
  [16]={
    .fullname="backupskip",
    .shortname="bsk",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_bsk,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [17]={
    .fullname="belloff",
    .shortname="bo",
    .flags=0|kOptFlagComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_bo,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_belloff,
    .opt_expand_cb=expand_set_belloff,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "all", .size = sizeof("all") - 1 } },
  },
  [18]={
    .fullname="binary",
    .shortname="bin",
    .flags=0|kOptFlagRedrStat,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_bin,
    .immutable=false,
    .indir=OPT_BUF(BV_BIN),
    .opt_did_set_cb=did_set_binary,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [19]={
    .fullname="bomb",
    .flags=0|kOptFlagRedrStat|kOptFlagNoMkrc,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_bomb,
    .immutable=false,
    .indir=OPT_BUF(BV_BOMB),
    .opt_did_set_cb=did_set_eof_eol_fixeol_bomb,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [20]={
    .fullname="breakat",
    .shortname="brk",
    .flags=0|kOptFlagFlagList|kOptFlagRedrAll,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_breakat,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_breakat,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = " \t!@*-+;:,./?", .size = sizeof(" \t!@*-+;:,./?") - 1 } },
  },
  [21]={
    .fullname="breakindent",
    .shortname="bri",
    .flags=0|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_BRI),
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [22]={
    .fullname="breakindentopt",
    .shortname="briopt",
    .flags=0|kOptFlagOneComma|kOptFlagRedrBuf|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_BRIOPT),
    .opt_did_set_cb=did_set_breakindentopt,
    .opt_expand_cb=expand_set_breakindentopt,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [23]={
    .fullname="browsedir",
    .shortname="bsdir",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&options[23].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [24]={
    .fullname="bufhidden",
    .shortname="bh",
    .flags=0|kOptFlagNoGlob,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_bh,
    .immutable=false,
    .indir=OPT_BUF(BV_BH),
    .opt_did_set_cb=did_set_bufhidden,
    .opt_expand_cb=expand_set_bufhidden,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [25]={
    .fullname="buflisted",
    .shortname="bl",
    .flags=0|kOptFlagNoGlob,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_bl,
    .immutable=false,
    .indir=OPT_BUF(BV_BL),
    .opt_did_set_cb=did_set_buflisted,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [26]={
    .fullname="buftype",
    .shortname="bt",
    .flags=0|kOptFlagNoGlob,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_bt,
    .immutable=false,
    .indir=OPT_BUF(BV_BT),
    .opt_did_set_cb=did_set_buftype,
    .opt_expand_cb=expand_set_buftype,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [27]={
    .fullname="casemap",
    .shortname="cmp",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_cmp,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_casemap,
    .opt_expand_cb=expand_set_casemap,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "internal,keepascii", .size = sizeof("internal,keepascii") - 1 } },
  },
  [28]={
    .fullname="cdhome",
    .shortname="cdh",
    .flags=0|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_cdh,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [29]={
    .fullname="cdpath",
    .shortname="cd",
    .flags=0|kOptFlagComma|kOptFlagExpand|kOptFlagSecure|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_cdpath,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = ",,", .size = sizeof(",,") - 1 } },
  },
  [30]={
    .fullname="cedit",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_cedit,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_cedit,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = CTRL_F_STR, .size = sizeof(CTRL_F_STR) - 1 } },
  },
  [31]={
    .fullname="channel",
    .flags=0|kOptFlagNoDefault|kOptFlagNoMkrc,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_channel,
    .immutable=false,
    .indir=OPT_BUF(BV_CHANNEL),
    .def_val={ .type = kOptValTypeNumber, .data.number = 0L },
  },
  [32]={
    .fullname="charconvert",
    .shortname="ccv",
    .flags=0|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_ccv,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_optexpr,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [33]={
    .fullname="cindent",
    .shortname="cin",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_cin,
    .immutable=false,
    .indir=OPT_BUF(BV_CIN),
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [34]={
    .fullname="cinkeys",
    .shortname="cink",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_cink,
    .immutable=false,
    .indir=OPT_BUF(BV_CINK),
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "0{,0},0),0],:,0#,!^F,o,O,e", .size = sizeof("0{,0},0),0],:,0#,!^F,o,O,e") - 1 } },
  },
  [35]={
    .fullname="cinoptions",
    .shortname="cino",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_cino,
    .immutable=false,
    .indir=OPT_BUF(BV_CINO),
    .opt_did_set_cb=did_set_cinoptions,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [36]={
    .fullname="cinscopedecls",
    .shortname="cinsd",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_cinsd,
    .immutable=false,
    .indir=OPT_BUF(BV_CINSD),
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "public,protected,private", .size = sizeof("public,protected,private") - 1 } },
  },
  [37]={
    .fullname="cinwords",
    .shortname="cinw",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_cinw,
    .immutable=false,
    .indir=OPT_BUF(BV_CINW),
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "if,else,while,do,for,switch", .size = sizeof("if,else,while,do,for,switch") - 1 } },
  },
  [38]={
    .fullname="clipboard",
    .shortname="cb",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_cb,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_clipboard,
    .opt_expand_cb=expand_set_clipboard,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [39]={
    .fullname="cmdheight",
    .shortname="ch",
    .flags=0|kOptFlagRedrAll,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_ch,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_cmdheight,
    .def_val={ .type = kOptValTypeNumber, .data.number = 1L },
  },
  [40]={
    .fullname="cmdwinheight",
    .shortname="cwh",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_cwh,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 7L },
  },
  [41]={
    .fullname="colorcolumn",
    .shortname="cc",
    .flags=0|kOptFlagOneComma|kOptFlagRedrWin|kOptFlagHLOnly|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_CC),
    .opt_did_set_cb=did_set_colorcolumn,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [42]={
    .fullname="columns",
    .shortname="co",
    .flags=0|kOptFlagNoMkrc,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_columns,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_lines_or_columns,
    .def_val={ .type = kOptValTypeNumber, .data.number = DFLT_COLS },
  },
  [43]={
    .fullname="comments",
    .shortname="com",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_com,
    .immutable=false,
    .indir=OPT_BUF(BV_COM),
    .opt_did_set_cb=did_set_comments,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "s1:/*,mb:*,ex:*/,://,b:#,:%,:XCOMM,n:>,fb:-,fb:•", .size = sizeof("s1:/*,mb:*,ex:*/,://,b:#,:%,:XCOMM,n:>,fb:-,fb:•") - 1 } },
  },
  [44]={
    .fullname="commentstring",
    .shortname="cms",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_cms,
    .immutable=false,
    .indir=OPT_BUF(BV_CMS),
    .opt_did_set_cb=did_set_commentstring,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [45]={
    .fullname="compatible",
    .shortname="cp",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&options[45].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [46]={
    .fullname="complete",
    .shortname="cpt",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_cpt,
    .immutable=false,
    .indir=OPT_BUF(BV_CPT),
    .opt_did_set_cb=did_set_complete,
    .opt_expand_cb=expand_set_complete,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = ".,w,b,u,t", .size = sizeof(".,w,b,u,t") - 1 } },
  },
  [47]={
    .fullname="completefunc",
    .shortname="cfu",
    .flags=0|kOptFlagSecure|kOptFlagFunc,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_cfu,
    .immutable=false,
    .indir=OPT_BUF(BV_CFU),
    .opt_did_set_cb=did_set_completefunc,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [48]={
    .fullname="completeitemalign",
    .shortname="cia",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_cia,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_completeitemalign,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "abbr,kind,menu", .size = sizeof("abbr,kind,menu") - 1 } },
  },
  [49]={
    .fullname="completeopt",
    .shortname="cot",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_cot,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_COT)),
    .opt_did_set_cb=did_set_completeopt,
    .opt_expand_cb=expand_set_completeopt,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "menu,preview", .size = sizeof("menu,preview") - 1 } },
  },
  [50]={
    .fullname="completeslash",
    .shortname="csl",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
#if defined(BACKSLASH_IN_FILENAME)
    .var=&p_csl,
    .immutable=false,
    .indir=OPT_BUF(BV_CSL),
    .opt_did_set_cb=did_set_completeslash,
    .opt_expand_cb=expand_set_completeslash,
#else
    .var=&options[50].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
#endif
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [51]={
    .fullname="concealcursor",
    .shortname="cocu",
    .flags=0|kOptFlagFlagList|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_COCU),
    .opt_did_set_cb=did_set_concealcursor,
    .opt_expand_cb=expand_set_concealcursor,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [52]={
    .fullname="conceallevel",
    .shortname="cole",
    .flags=0|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_COLE),
    .def_val={ .type = kOptValTypeNumber, .data.number = 0L },
  },
  [53]={
    .fullname="confirm",
    .shortname="cf",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_confirm,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [54]={
    .fullname="copyindent",
    .shortname="ci",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_ci,
    .immutable=false,
    .indir=OPT_BUF(BV_CI),
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [55]={
    .fullname="cpoptions",
    .shortname="cpo",
    .flags=0|kOptFlagFlagList|kOptFlagRedrAll,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_cpo,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_cpoptions,
    .opt_expand_cb=expand_set_cpoptions,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = CPO_VIM, .size = sizeof(CPO_VIM) - 1 } },
  },
  [56]={
    .fullname="cursorbind",
    .shortname="crb",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_CRBIND),
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [57]={
    .fullname="cursorcolumn",
    .shortname="cuc",
    .flags=0|kOptFlagRedrWin|kOptFlagHLOnly,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_CUC),
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [58]={
    .fullname="cursorline",
    .shortname="cul",
    .flags=0|kOptFlagRedrWin|kOptFlagHLOnly,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_CUL),
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [59]={
    .fullname="cursorlineopt",
    .shortname="culopt",
    .flags=0|kOptFlagOneComma|kOptFlagRedrWin|kOptFlagHLOnly|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_CULOPT),
    .opt_did_set_cb=did_set_cursorlineopt,
    .opt_expand_cb=expand_set_cursorlineopt,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "both", .size = sizeof("both") - 1 } },
  },
  [60]={
    .fullname="debug",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_debug,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_debug,
    .opt_expand_cb=expand_set_debug,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [61]={
    .fullname="define",
    .shortname="def",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_def,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_DEF)),
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [62]={
    .fullname="delcombine",
    .shortname="deco",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_deco,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [63]={
    .fullname="dictionary",
    .shortname="dict",
    .flags=0|kOptFlagOneComma|kOptFlagExpand|kOptFlagNDname|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_dict,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_DICT)),
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [64]={
    .fullname="diff",
    .flags=0|kOptFlagRedrWin|kOptFlagNoGlob,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_DIFF),
    .opt_did_set_cb=did_set_diff,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [65]={
    .fullname="diffexpr",
    .shortname="dex",
    .flags=0|kOptFlagCurswant|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_dex,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_optexpr,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [66]={
    .fullname="diffopt",
    .shortname="dip",
    .flags=0|kOptFlagOneComma|kOptFlagColon|kOptFlagRedrWin|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_dip,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_diffopt,
    .opt_expand_cb=expand_set_diffopt,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "internal,filler,closeoff", .size = sizeof("internal,filler,closeoff") - 1 } },
  },
  [67]={
    .fullname="digraph",
    .shortname="dg",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_dg,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [68]={
    .fullname="directory",
    .shortname="dir",
    .flags=0|kOptFlagOneComma|kOptFlagExpand|kOptFlagNoDefExp|kOptFlagSecure|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_dir,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [69]={
    .fullname="display",
    .shortname="dy",
    .flags=0|kOptFlagOneComma|kOptFlagRedrAll|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_dy,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_display,
    .opt_expand_cb=expand_set_display,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "lastline", .size = sizeof("lastline") - 1 } },
  },
  [70]={
    .fullname="eadirection",
    .shortname="ead",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_ead,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_eadirection,
    .opt_expand_cb=expand_set_eadirection,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "both", .size = sizeof("both") - 1 } },
  },
  [71]={
    .fullname="edcompatible",
    .shortname="ed",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&options[71].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [72]={
    .fullname="emoji",
    .shortname="emo",
    .flags=0|kOptFlagRedrAll|kOptFlagUIOption,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_emoji,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_ambiwidth,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [73]={
    .fullname="encoding",
    .shortname="enc",
    .flags=0|kOptFlagNoML,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_enc,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_encoding,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = ENC_DFLT, .size = sizeof(ENC_DFLT) - 1 } },
  },
  [74]={
    .fullname="endoffile",
    .shortname="eof",
    .flags=0|kOptFlagRedrStat|kOptFlagNoMkrc,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_eof,
    .immutable=false,
    .indir=OPT_BUF(BV_EOF),
    .opt_did_set_cb=did_set_eof_eol_fixeol_bomb,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [75]={
    .fullname="endofline",
    .shortname="eol",
    .flags=0|kOptFlagRedrStat|kOptFlagNoMkrc,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_eol,
    .immutable=false,
    .indir=OPT_BUF(BV_EOL),
    .opt_did_set_cb=did_set_eof_eol_fixeol_bomb,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [76]={
    .fullname="equalalways",
    .shortname="ea",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_ea,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_equalalways,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [77]={
    .fullname="equalprg",
    .shortname="ep",
    .flags=0|kOptFlagExpand|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_ep,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_EP)),
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [78]={
    .fullname="errorbells",
    .shortname="eb",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_eb,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [79]={
    .fullname="errorfile",
    .shortname="ef",
    .flags=0|kOptFlagExpand|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_ef,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = DFLT_ERRORFILE, .size = sizeof(DFLT_ERRORFILE) - 1 } },
  },
  [80]={
    .fullname="errorformat",
    .shortname="efm",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_efm,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_EFM)),
    .def_val={ .type = kOptValTypeString, .data.string = { .data = DFLT_EFM, .size = sizeof(DFLT_EFM) - 1 } },
  },
  [81]={
    .fullname="eventignore",
    .shortname="ei",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_ei,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_eventignore,
    .opt_expand_cb=expand_set_eventignore,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [82]={
    .fullname="expandtab",
    .shortname="et",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_et,
    .immutable=false,
    .indir=OPT_BUF(BV_ET),
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [83]={
    .fullname="exrc",
    .shortname="ex",
    .flags=0|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_exrc,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [84]={
    .fullname="fileencoding",
    .shortname="fenc",
    .flags=0|kOptFlagRedrStat|kOptFlagRedrBuf|kOptFlagNoMkrc,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_fenc,
    .immutable=false,
    .indir=OPT_BUF(BV_FENC),
    .opt_did_set_cb=did_set_encoding,
    .opt_expand_cb=expand_set_encoding,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [85]={
    .fullname="fileencodings",
    .shortname="fencs",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_fencs,
    .immutable=false,
    .indir=PV_NONE,
    .opt_expand_cb=expand_set_encoding,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "ucs-bom,utf-8,default,latin1", .size = sizeof("ucs-bom,utf-8,default,latin1") - 1 } },
  },
  [86]={
    .fullname="fileformat",
    .shortname="ff",
    .flags=0|kOptFlagCurswant|kOptFlagRedrStat|kOptFlagNoMkrc,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_ff,
    .immutable=false,
    .indir=OPT_BUF(BV_FF),
    .opt_did_set_cb=did_set_fileformat,
    .opt_expand_cb=expand_set_fileformat,
#if defined(USE_CRNL)
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "dos", .size = sizeof("dos") - 1 } },
#else
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "unix", .size = sizeof("unix") - 1 } },
#endif
  },
  [87]={
    .fullname="fileformats",
    .shortname="ffs",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_ffs,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_fileformats,
    .opt_expand_cb=expand_set_fileformat,
#if defined(USE_CRNL)
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "dos,unix", .size = sizeof("dos,unix") - 1 } },
#else
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "unix,dos", .size = sizeof("unix,dos") - 1 } },
#endif
  },
  [88]={
    .fullname="fileignorecase",
    .shortname="fic",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_fic,
    .immutable=false,
    .indir=PV_NONE,
#if defined(CASE_INSENSITIVE_FILENAME)
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
#endif
  },
  [89]={
    .fullname="filetype",
    .shortname="ft",
    .flags=0|kOptFlagNoGlob|kOptFlagNFname,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_ft,
    .immutable=false,
    .indir=OPT_BUF(BV_FT),
    .opt_did_set_cb=did_set_filetype_or_syntax,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [90]={
    .fullname="fillchars",
    .shortname="fcs",
    .flags=0|kOptFlagOneComma|kOptFlagRedrWin|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_fcs,
    .immutable=false,
    .indir=OPT_BOTH(OPT_WIN(WV_FCS)),
    .opt_did_set_cb=did_set_chars_option,
    .opt_expand_cb=expand_set_chars_option,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [91]={
    .fullname="findfunc",
    .shortname="ffu",
    .flags=0|kOptFlagSecure|kOptFlagFunc,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_ffu,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_FFU)),
    .opt_did_set_cb=did_set_findfunc,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [92]={
    .fullname="fixendofline",
    .shortname="fixeol",
    .flags=0|kOptFlagRedrStat,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_fixeol,
    .immutable=false,
    .indir=OPT_BUF(BV_FIXEOL),
    .opt_did_set_cb=did_set_eof_eol_fixeol_bomb,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [93]={
    .fullname="foldclose",
    .shortname="fcl",
    .flags=0|kOptFlagOneComma|kOptFlagRedrWin|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_fcl,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_foldclose,
    .opt_expand_cb=expand_set_foldclose,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [94]={
    .fullname="foldcolumn",
    .shortname="fdc",
    .flags=0|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_FDC),
    .opt_did_set_cb=did_set_foldcolumn,
    .opt_expand_cb=expand_set_foldcolumn,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "0", .size = sizeof("0") - 1 } },
  },
  [95]={
    .fullname="foldenable",
    .shortname="fen",
    .flags=0|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_FEN),
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [96]={
    .fullname="foldexpr",
    .shortname="fde",
    .flags=0|kOptFlagRedrWin|kOptFlagMLE,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_FDE),
    .opt_did_set_cb=did_set_foldexpr,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "0", .size = sizeof("0") - 1 } },
  },
  [97]={
    .fullname="foldignore",
    .shortname="fdi",
    .flags=0|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_FDI),
    .opt_did_set_cb=did_set_foldignore,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "#", .size = sizeof("#") - 1 } },
  },
  [98]={
    .fullname="foldlevel",
    .shortname="fdl",
    .flags=0|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_FDL),
    .opt_did_set_cb=did_set_foldlevel,
    .def_val={ .type = kOptValTypeNumber, .data.number = 0L },
  },
  [99]={
    .fullname="foldlevelstart",
    .shortname="fdls",
    .flags=0|kOptFlagCurswant,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_fdls,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = -1L },
  },
  [100]={
    .fullname="foldmarker",
    .shortname="fmr",
    .flags=0|kOptFlagOneComma|kOptFlagRedrWin|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_FMR),
    .opt_did_set_cb=did_set_foldmarker,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "{{{,}}}", .size = sizeof("{{{,}}}") - 1 } },
  },
  [101]={
    .fullname="foldmethod",
    .shortname="fdm",
    .flags=0|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_FDM),
    .opt_did_set_cb=did_set_foldmethod,
    .opt_expand_cb=expand_set_foldmethod,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "manual", .size = sizeof("manual") - 1 } },
  },
  [102]={
    .fullname="foldminlines",
    .shortname="fml",
    .flags=0|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_FML),
    .opt_did_set_cb=did_set_foldminlines,
    .def_val={ .type = kOptValTypeNumber, .data.number = 1L },
  },
  [103]={
    .fullname="foldnestmax",
    .shortname="fdn",
    .flags=0|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_FDN),
    .opt_did_set_cb=did_set_foldnestmax,
    .def_val={ .type = kOptValTypeNumber, .data.number = 20L },
  },
  [104]={
    .fullname="foldopen",
    .shortname="fdo",
    .flags=0|kOptFlagOneComma|kOptFlagCurswant|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_fdo,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_foldopen,
    .opt_expand_cb=expand_set_foldopen,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "block,hor,mark,percent,quickfix,search,tag,undo", .size = sizeof("block,hor,mark,percent,quickfix,search,tag,undo") - 1 } },
  },
  [105]={
    .fullname="foldtext",
    .shortname="fdt",
    .flags=0|kOptFlagRedrWin|kOptFlagMLE,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_FDT),
    .opt_did_set_cb=did_set_optexpr,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "foldtext()", .size = sizeof("foldtext()") - 1 } },
  },
  [106]={
    .fullname="formatexpr",
    .shortname="fex",
    .flags=0|kOptFlagMLE,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_fex,
    .immutable=false,
    .indir=OPT_BUF(BV_FEX),
    .opt_did_set_cb=did_set_optexpr,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [107]={
    .fullname="formatlistpat",
    .shortname="flp",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_flp,
    .immutable=false,
    .indir=OPT_BUF(BV_FLP),
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "^\\s*\\d\\+[\\]:.)}\\t ]\\s*", .size = sizeof("^\\s*\\d\\+[\\]:.)}\\t ]\\s*") - 1 } },
  },
  [108]={
    .fullname="formatoptions",
    .shortname="fo",
    .flags=0|kOptFlagFlagList,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_fo,
    .immutable=false,
    .indir=OPT_BUF(BV_FO),
    .opt_did_set_cb=did_set_formatoptions,
    .opt_expand_cb=expand_set_formatoptions,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = DFLT_FO_VIM, .size = sizeof(DFLT_FO_VIM) - 1 } },
  },
  [109]={
    .fullname="formatprg",
    .shortname="fp",
    .flags=0|kOptFlagExpand|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_fp,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_FP)),
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [110]={
    .fullname="fsync",
    .shortname="fs",
    .flags=0|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_fs,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [111]={
    .fullname="gdefault",
    .shortname="gd",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_gd,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [112]={
    .fullname="grepformat",
    .shortname="gfm",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_gefm,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = DFLT_GREPFORMAT, .size = sizeof(DFLT_GREPFORMAT) - 1 } },
  },
  [113]={
    .fullname="grepprg",
    .shortname="gp",
    .flags=0|kOptFlagExpand|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_gp,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_GP)),
#if defined(MSWIN)
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "findstr /n $* nul", .size = sizeof("findstr /n $* nul") - 1 } },
#else
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "grep -HIn $* /dev/null", .size = sizeof("grep -HIn $* /dev/null") - 1 } },
#endif
  },
  [114]={
    .fullname="guicursor",
    .shortname="gcr",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_guicursor,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_guicursor,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "n-v-c-sm:block,i-ci-ve:ver25,r-cr-o:hor20", .size = sizeof("n-v-c-sm:block,i-ci-ve:ver25,r-cr-o:hor20") - 1 } },
  },
  [115]={
    .fullname="guifont",
    .shortname="gfn",
    .flags=0|kOptFlagOneComma|kOptFlagUIOption|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_guifont,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [116]={
    .fullname="guifontwide",
    .shortname="gfw",
    .flags=0|kOptFlagOneComma|kOptFlagUIOption|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_guifontwide,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [117]={
    .fullname="guioptions",
    .shortname="go",
    .flags=0|kOptFlagFlagList,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&options[117].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [118]={
    .fullname="guitablabel",
    .shortname="gtl",
    .flags=0|kOptFlagRedrWin|kOptFlagMLE,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&options[118].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [119]={
    .fullname="guitabtooltip",
    .shortname="gtt",
    .flags=0|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&options[119].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [120]={
    .fullname="helpfile",
    .shortname="hf",
    .flags=0|kOptFlagExpand|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_hf,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_helpfile,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = DFLT_HELPFILE, .size = sizeof(DFLT_HELPFILE) - 1 } },
  },
  [121]={
    .fullname="helpheight",
    .shortname="hh",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_hh,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_helpheight,
    .def_val={ .type = kOptValTypeNumber, .data.number = 20L },
  },
  [122]={
    .fullname="helplang",
    .shortname="hlg",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_hlg,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_helplang,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [123]={
    .fullname="hidden",
    .shortname="hid",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_hid,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [124]={
    .fullname="highlight",
    .shortname="hl",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_hl,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_highlight,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = HIGHLIGHT_INIT, .size = sizeof(HIGHLIGHT_INIT) - 1 } },
  },
  [125]={
    .fullname="history",
    .shortname="hi",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_hi,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 10000L },
  },
  [126]={
    .fullname="hkmap",
    .shortname="hk",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&options[126].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [127]={
    .fullname="hkmapp",
    .shortname="hkp",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&options[127].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [128]={
    .fullname="hlsearch",
    .shortname="hls",
    .flags=0|kOptFlagRedrAll|kOptFlagHLOnly,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_hls,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_hlsearch,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [129]={
    .fullname="icon",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_icon,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_title_icon,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [130]={
    .fullname="iconstring",
    .flags=0|kOptFlagMLE,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_iconstring,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_iconstring,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [131]={
    .fullname="ignorecase",
    .shortname="ic",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_ic,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_ignorecase,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [132]={
    .fullname="imcmdline",
    .shortname="imc",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&options[132].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [133]={
    .fullname="imdisable",
    .shortname="imd",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&options[133].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [134]={
    .fullname="iminsert",
    .shortname="imi",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_iminsert,
    .immutable=false,
    .indir=OPT_BUF(BV_IMI),
    .opt_did_set_cb=did_set_iminsert,
    .def_val={ .type = kOptValTypeNumber, .data.number = B_IMODE_NONE },
  },
  [135]={
    .fullname="imsearch",
    .shortname="ims",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_imsearch,
    .immutable=false,
    .indir=OPT_BUF(BV_IMS),
    .def_val={ .type = kOptValTypeNumber, .data.number = B_IMODE_USE_INSERT },
  },
  [136]={
    .fullname="inccommand",
    .shortname="icm",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_icm,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_inccommand,
    .opt_expand_cb=expand_set_inccommand,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "nosplit", .size = sizeof("nosplit") - 1 } },
  },
  [137]={
    .fullname="include",
    .shortname="inc",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_inc,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_INC)),
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [138]={
    .fullname="includeexpr",
    .shortname="inex",
    .flags=0|kOptFlagMLE,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_inex,
    .immutable=false,
    .indir=OPT_BUF(BV_INEX),
    .opt_did_set_cb=did_set_optexpr,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [139]={
    .fullname="incsearch",
    .shortname="is",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_is,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [140]={
    .fullname="indentexpr",
    .shortname="inde",
    .flags=0|kOptFlagMLE,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_inde,
    .immutable=false,
    .indir=OPT_BUF(BV_INDE),
    .opt_did_set_cb=did_set_optexpr,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [141]={
    .fullname="indentkeys",
    .shortname="indk",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_indk,
    .immutable=false,
    .indir=OPT_BUF(BV_INDK),
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "0{,0},0),0],:,0#,!^F,o,O,e", .size = sizeof("0{,0},0),0],:,0#,!^F,o,O,e") - 1 } },
  },
  [142]={
    .fullname="infercase",
    .shortname="inf",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_inf,
    .immutable=false,
    .indir=OPT_BUF(BV_INF),
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [143]={
    .fullname="insertmode",
    .shortname="im",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&options[143].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [144]={
    .fullname="isfname",
    .shortname="isf",
    .flags=0|kOptFlagComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_isf,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_isopt,
#if defined(BACKSLASH_IN_FILENAME)
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "@,48-57,/,\\,.,-,_,+,,,#,$,%,{,},[,],@-@,!,~,=", .size = sizeof("@,48-57,/,\\,.,-,_,+,,,#,$,%,{,},[,],@-@,!,~,=") - 1 } },
#else
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "@,48-57,/,.,-,_,+,,,#,$,%,~,=", .size = sizeof("@,48-57,/,.,-,_,+,,,#,$,%,~,=") - 1 } },
#endif
  },
  [145]={
    .fullname="isident",
    .shortname="isi",
    .flags=0|kOptFlagComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_isi,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_isopt,
#if defined(MSWIN)
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "@,48-57,_,128-167,224-235", .size = sizeof("@,48-57,_,128-167,224-235") - 1 } },
#else
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "@,48-57,_,192-255", .size = sizeof("@,48-57,_,192-255") - 1 } },
#endif
  },
  [146]={
    .fullname="iskeyword",
    .shortname="isk",
    .flags=0|kOptFlagComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_isk,
    .immutable=false,
    .indir=OPT_BUF(BV_ISK),
    .opt_did_set_cb=did_set_iskeyword,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "@,48-57,_,192-255", .size = sizeof("@,48-57,_,192-255") - 1 } },
  },
  [147]={
    .fullname="isprint",
    .shortname="isp",
    .flags=0|kOptFlagComma|kOptFlagRedrAll|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_isp,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_isopt,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "@,161-255", .size = sizeof("@,161-255") - 1 } },
  },
  [148]={
    .fullname="joinspaces",
    .shortname="js",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_js,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [149]={
    .fullname="jumpoptions",
    .shortname="jop",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_jop,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_jumpoptions,
    .opt_expand_cb=expand_set_jumpoptions,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "clean", .size = sizeof("clean") - 1 } },
  },
  [150]={
    .fullname="keymap",
    .shortname="kmp",
    .flags=0|kOptFlagRedrStat|kOptFlagRedrBuf|kOptFlagNFname|kOptFlagPriMkrc,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_keymap,
    .immutable=false,
    .indir=OPT_BUF(BV_KMAP),
    .opt_did_set_cb=did_set_keymap,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [151]={
    .fullname="keymodel",
    .shortname="km",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_km,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_keymodel,
    .opt_expand_cb=expand_set_keymodel,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [152]={
    .fullname="keywordprg",
    .shortname="kp",
    .flags=0|kOptFlagExpand|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_kp,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_KP)),
    .def_val={ .type = kOptValTypeString, .data.string = { .data = ":Man", .size = sizeof(":Man") - 1 } },
  },
  [153]={
    .fullname="langmap",
    .shortname="lmap",
    .flags=0|kOptFlagOneComma|kOptFlagSecure|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_langmap,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_langmap,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [154]={
    .fullname="langmenu",
    .shortname="lm",
    .flags=0|kOptFlagNFname,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_lm,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [155]={
    .fullname="langnoremap",
    .shortname="lnr",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_lnr,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_langnoremap,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [156]={
    .fullname="langremap",
    .shortname="lrm",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_lrm,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_langremap,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [157]={
    .fullname="laststatus",
    .shortname="ls",
    .flags=0|kOptFlagRedrAll,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_ls,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_laststatus,
    .def_val={ .type = kOptValTypeNumber, .data.number = 2L },
  },
  [158]={
    .fullname="lazyredraw",
    .shortname="lz",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_lz,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [159]={
    .fullname="linebreak",
    .shortname="lbr",
    .flags=0|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_LBR),
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [160]={
    .fullname="lines",
    .flags=0|kOptFlagNoMkrc,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_lines,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_lines_or_columns,
    .def_val={ .type = kOptValTypeNumber, .data.number = DFLT_ROWS },
  },
  [161]={
    .fullname="linespace",
    .shortname="lsp",
    .flags=0|kOptFlagUIOption,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_linespace,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 0L },
  },
  [162]={
    .fullname="lisp",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_lisp,
    .immutable=false,
    .indir=OPT_BUF(BV_LISP),
    .opt_did_set_cb=did_set_lisp,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [163]={
    .fullname="lispoptions",
    .shortname="lop",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_lop,
    .immutable=false,
    .indir=OPT_BUF(BV_LOP),
    .opt_did_set_cb=did_set_lispoptions,
    .opt_expand_cb=expand_set_lispoptions,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [164]={
    .fullname="lispwords",
    .shortname="lw",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_lispwords,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_LW)),
    .def_val={ .type = kOptValTypeString, .data.string = { .data = LISPWORD_VALUE, .size = sizeof(LISPWORD_VALUE) - 1 } },
  },
  [165]={
    .fullname="list",
    .flags=0|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_LIST),
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [166]={
    .fullname="listchars",
    .shortname="lcs",
    .flags=0|kOptFlagOneComma|kOptFlagRedrWin|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_lcs,
    .immutable=false,
    .indir=OPT_BOTH(OPT_WIN(WV_LCS)),
    .opt_did_set_cb=did_set_chars_option,
    .opt_expand_cb=expand_set_chars_option,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "tab:> ,trail:-,nbsp:+", .size = sizeof("tab:> ,trail:-,nbsp:+") - 1 } },
  },
  [167]={
    .fullname="loadplugins",
    .shortname="lpl",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_lpl,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [168]={
    .fullname="magic",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_magic,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [169]={
    .fullname="makeef",
    .shortname="mef",
    .flags=0|kOptFlagExpand|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_mef,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [170]={
    .fullname="makeencoding",
    .shortname="menc",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_menc,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_MENC)),
    .opt_did_set_cb=did_set_encoding,
    .opt_expand_cb=expand_set_encoding,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [171]={
    .fullname="makeprg",
    .shortname="mp",
    .flags=0|kOptFlagExpand|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_mp,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_MP)),
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "make", .size = sizeof("make") - 1 } },
  },
  [172]={
    .fullname="matchpairs",
    .shortname="mps",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_mps,
    .immutable=false,
    .indir=OPT_BUF(BV_MPS),
    .opt_did_set_cb=did_set_matchpairs,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "(:),{:},[:]", .size = sizeof("(:),{:},[:]") - 1 } },
  },
  [173]={
    .fullname="matchtime",
    .shortname="mat",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_mat,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 5L },
  },
  [174]={
    .fullname="maxcombine",
    .shortname="mco",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_mco,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = MAX_MCO },
  },
  [175]={
    .fullname="maxfuncdepth",
    .shortname="mfd",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_mfd,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 100L },
  },
  [176]={
    .fullname="maxmapdepth",
    .shortname="mmd",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_mmd,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 1000L },
  },
  [177]={
    .fullname="maxmempattern",
    .shortname="mmp",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_mmp,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 1000L },
  },
  [178]={
    .fullname="menuitems",
    .shortname="mis",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_mis,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 25L },
  },
  [179]={
    .fullname="mkspellmem",
    .shortname="msm",
    .flags=0|kOptFlagExpand|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_msm,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_mkspellmem,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "460000,2000,500", .size = sizeof("460000,2000,500") - 1 } },
  },
  [180]={
    .fullname="modeline",
    .shortname="ml",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_ml,
    .immutable=false,
    .indir=OPT_BUF(BV_ML),
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [181]={
    .fullname="modelineexpr",
    .shortname="mle",
    .flags=0|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_mle,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [182]={
    .fullname="modelines",
    .shortname="mls",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_mls,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 5L },
  },
  [183]={
    .fullname="modifiable",
    .shortname="ma",
    .flags=0|kOptFlagNoGlob,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_ma,
    .immutable=false,
    .indir=OPT_BUF(BV_MA),
    .opt_did_set_cb=did_set_modifiable,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [184]={
    .fullname="modified",
    .shortname="mod",
    .flags=0|kOptFlagRedrStat|kOptFlagNoMkrc,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_mod,
    .immutable=false,
    .indir=OPT_BUF(BV_MOD),
    .opt_did_set_cb=did_set_modified,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [185]={
    .fullname="more",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_more,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [186]={
    .fullname="mouse",
    .flags=0|kOptFlagFlagList,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_mouse,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_mouse,
    .opt_expand_cb=expand_set_mouse,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "nvi", .size = sizeof("nvi") - 1 } },
  },
  [187]={
    .fullname="mousefocus",
    .shortname="mousef",
    .flags=0|kOptFlagUIOption,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_mousef,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [188]={
    .fullname="mousehide",
    .shortname="mh",
    .flags=0|kOptFlagUIOption,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_mh,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [189]={
    .fullname="mousemodel",
    .shortname="mousem",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_mousem,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_mousemodel,
    .opt_expand_cb=expand_set_mousemodel,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "popup_setpos", .size = sizeof("popup_setpos") - 1 } },
  },
  [190]={
    .fullname="mousemoveevent",
    .shortname="mousemev",
    .flags=0|kOptFlagUIOption,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_mousemev,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [191]={
    .fullname="mousescroll",
    .flags=0|kOptFlagComma,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_mousescroll,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_mousescroll,
    .opt_expand_cb=expand_set_mousescroll,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "ver:3,hor:6", .size = sizeof("ver:3,hor:6") - 1 } },
  },
  [192]={
    .fullname="mouseshape",
    .shortname="mouses",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&options[192].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [193]={
    .fullname="mousetime",
    .shortname="mouset",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_mouset,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 500L },
  },
  [194]={
    .fullname="nrformats",
    .shortname="nf",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_nf,
    .immutable=false,
    .indir=OPT_BUF(BV_NF),
    .opt_did_set_cb=did_set_nrformats,
    .opt_expand_cb=expand_set_nrformats,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "bin,hex", .size = sizeof("bin,hex") - 1 } },
  },
  [195]={
    .fullname="number",
    .shortname="nu",
    .flags=0|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_NU),
    .opt_did_set_cb=did_set_number_relativenumber,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [196]={
    .fullname="numberwidth",
    .shortname="nuw",
    .flags=0|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_NUW),
    .opt_did_set_cb=did_set_numberwidth,
    .def_val={ .type = kOptValTypeNumber, .data.number = 4L },
  },
  [197]={
    .fullname="omnifunc",
    .shortname="ofu",
    .flags=0|kOptFlagSecure|kOptFlagFunc,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_ofu,
    .immutable=false,
    .indir=OPT_BUF(BV_OFU),
    .opt_did_set_cb=did_set_omnifunc,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [198]={
    .fullname="opendevice",
    .shortname="odev",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&options[198].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [199]={
    .fullname="operatorfunc",
    .shortname="opfunc",
    .flags=0|kOptFlagSecure|kOptFlagFunc,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_opfunc,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_operatorfunc,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [200]={
    .fullname="packpath",
    .shortname="pp",
    .flags=0|kOptFlagOneComma|kOptFlagExpand|kOptFlagSecure|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_pp,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_runtimepackpath,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [201]={
    .fullname="paragraphs",
    .shortname="para",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_para,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "IPLPPPQPP TPHPLIPpLpItpplpipbp", .size = sizeof("IPLPPPQPP TPHPLIPpLpItpplpipbp") - 1 } },
  },
  [202]={
    .fullname="paste",
    .flags=0|kOptFlagPriMkrc,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_paste,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_paste,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [203]={
    .fullname="pastetoggle",
    .shortname="pt",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&options[203].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [204]={
    .fullname="patchexpr",
    .shortname="pex",
    .flags=0|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_pex,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_optexpr,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [205]={
    .fullname="patchmode",
    .shortname="pm",
    .flags=0|kOptFlagNFname,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_pm,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_backupext_or_patchmode,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [206]={
    .fullname="path",
    .shortname="pa",
    .flags=0|kOptFlagComma|kOptFlagExpand|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_path,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_PATH)),
    .def_val={ .type = kOptValTypeString, .data.string = { .data = ".,,", .size = sizeof(".,,") - 1 } },
  },
  [207]={
    .fullname="preserveindent",
    .shortname="pi",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_pi,
    .immutable=false,
    .indir=OPT_BUF(BV_PI),
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [208]={
    .fullname="previewheight",
    .shortname="pvh",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_pvh,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 12L },
  },
  [209]={
    .fullname="previewwindow",
    .shortname="pvw",
    .flags=0|kOptFlagRedrStat|kOptFlagNoGlob,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_PVW),
    .opt_did_set_cb=did_set_previewwindow,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [210]={
    .fullname="prompt",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&options[210].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [211]={
    .fullname="pumblend",
    .shortname="pb",
    .flags=0|kOptFlagUIOption,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_pb,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_pumblend,
    .def_val={ .type = kOptValTypeNumber, .data.number = 0L },
  },
  [212]={
    .fullname="pumheight",
    .shortname="ph",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_ph,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 0L },
  },
  [213]={
    .fullname="pumwidth",
    .shortname="pw",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_pw,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 15L },
  },
  [214]={
    .fullname="pyxversion",
    .shortname="pyx",
    .flags=0|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_pyx,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 3L },
  },
  [215]={
    .fullname="quickfixtextfunc",
    .shortname="qftf",
    .flags=0|kOptFlagSecure|kOptFlagFunc,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_qftf,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_quickfixtextfunc,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [216]={
    .fullname="quoteescape",
    .shortname="qe",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_qe,
    .immutable=false,
    .indir=OPT_BUF(BV_QE),
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "\\", .size = sizeof("\\") - 1 } },
  },
  [217]={
    .fullname="readonly",
    .shortname="ro",
    .flags=0|kOptFlagRedrStat|kOptFlagNoGlob,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_ro,
    .immutable=false,
    .indir=OPT_BUF(BV_RO),
    .opt_did_set_cb=did_set_readonly,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [218]={
    .fullname="redrawdebug",
    .shortname="rdb",
    .flags=0|kOptFlagOneComma,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_rdb,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_redrawdebug,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [219]={
    .fullname="redrawtime",
    .shortname="rdt",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_rdt,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 2000L },
  },
  [220]={
    .fullname="regexpengine",
    .shortname="re",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_re,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 0L },
  },
  [221]={
    .fullname="relativenumber",
    .shortname="rnu",
    .flags=0|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_RNU),
    .opt_did_set_cb=did_set_number_relativenumber,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [222]={
    .fullname="remap",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&options[222].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [223]={
    .fullname="report",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_report,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 2L },
  },
  [224]={
    .fullname="revins",
    .shortname="ri",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_ri,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [225]={
    .fullname="rightleft",
    .shortname="rl",
    .flags=0|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_RL),
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [226]={
    .fullname="rightleftcmd",
    .shortname="rlc",
    .flags=0|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_RLC),
    .opt_did_set_cb=did_set_rightleftcmd,
    .opt_expand_cb=expand_set_rightleftcmd,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "search", .size = sizeof("search") - 1 } },
  },
  [227]={
    .fullname="ruler",
    .shortname="ru",
    .flags=0|kOptFlagRedrStat,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_ru,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [228]={
    .fullname="rulerformat",
    .shortname="ruf",
    .flags=0|kOptFlagRedrStat|kOptFlagMLE,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_ruf,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_rulerformat,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [229]={
    .fullname="runtimepath",
    .shortname="rtp",
    .flags=0|kOptFlagOneComma|kOptFlagExpand|kOptFlagNoDefExp|kOptFlagSecure|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_rtp,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_runtimepackpath,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [230]={
    .fullname="scroll",
    .shortname="scr",
    .flags=0|kOptFlagNoMkrc,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_SCROLL),
    .def_val={ .type = kOptValTypeNumber, .data.number = 0L },
  },
  [231]={
    .fullname="scrollback",
    .shortname="scbk",
    .flags=0|kOptFlagRedrBuf,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_scbk,
    .immutable=false,
    .indir=OPT_BUF(BV_SCBK),
    .opt_did_set_cb=did_set_scrollback,
    .def_val={ .type = kOptValTypeNumber, .data.number = -1L },
  },
  [232]={
    .fullname="scrollbind",
    .shortname="scb",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_SCBIND),
    .opt_did_set_cb=did_set_scrollbind,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [233]={
    .fullname="scrolljump",
    .shortname="sj",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_sj,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 1L },
  },
  [234]={
    .fullname="scrolloff",
    .shortname="so",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_so,
    .immutable=false,
    .indir=OPT_BOTH(OPT_WIN(WV_SO)),
    .def_val={ .type = kOptValTypeNumber, .data.number = 0L },
  },
  [235]={
    .fullname="scrollopt",
    .shortname="sbo",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_sbo,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_scrollopt,
    .opt_expand_cb=expand_set_scrollopt,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "ver,jump", .size = sizeof("ver,jump") - 1 } },
  },
  [236]={
    .fullname="sections",
    .shortname="sect",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_sections,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "SHNHH HUnhsh", .size = sizeof("SHNHH HUnhsh") - 1 } },
  },
  [237]={
    .fullname="secure",
    .flags=0|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_secure,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [238]={
    .fullname="selection",
    .shortname="sel",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_sel,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_selection,
    .opt_expand_cb=expand_set_selection,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "inclusive", .size = sizeof("inclusive") - 1 } },
  },
  [239]={
    .fullname="selectmode",
    .shortname="slm",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_slm,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_selectmode,
    .opt_expand_cb=expand_set_selectmode,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [240]={
    .fullname="sessionoptions",
    .shortname="ssop",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_ssop,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_sessionoptions,
    .opt_expand_cb=expand_set_sessionoptions,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "blank,buffers,curdir,folds,help,tabpages,winsize,terminal", .size = sizeof("blank,buffers,curdir,folds,help,tabpages,winsize,terminal") - 1 } },
  },
  [241]={
    .fullname="shada",
    .shortname="sd",
    .flags=0|kOptFlagOneComma|kOptFlagSecure|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_shada,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_shada,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "!,'100,<50,s10,h", .size = sizeof("!,'100,<50,s10,h") - 1 } },
  },
  [242]={
    .fullname="shadafile",
    .shortname="sdf",
    .flags=0|kOptFlagOneComma|kOptFlagExpand|kOptFlagSecure|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_shadafile,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [243]={
    .fullname="shell",
    .shortname="sh",
    .flags=0|kOptFlagExpand|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_sh,
    .immutable=false,
    .indir=PV_NONE,
#if defined(MSWIN)
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "cmd.exe", .size = sizeof("cmd.exe") - 1 } },
#else
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "sh", .size = sizeof("sh") - 1 } },
#endif
  },
  [244]={
    .fullname="shellcmdflag",
    .shortname="shcf",
    .flags=0|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_shcf,
    .immutable=false,
    .indir=PV_NONE,
#if defined(MSWIN)
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "/s /c", .size = sizeof("/s /c") - 1 } },
#else
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "-c", .size = sizeof("-c") - 1 } },
#endif
  },
  [245]={
    .fullname="shellpipe",
    .shortname="sp",
    .flags=0|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_sp,
    .immutable=false,
    .indir=PV_NONE,
#if defined(MSWIN)
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "2>&1| tee", .size = sizeof("2>&1| tee") - 1 } },
#else
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "| tee", .size = sizeof("| tee") - 1 } },
#endif
  },
  [246]={
    .fullname="shellquote",
    .shortname="shq",
    .flags=0|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_shq,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [247]={
    .fullname="shellredir",
    .shortname="srr",
    .flags=0|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_srr,
    .immutable=false,
    .indir=PV_NONE,
#if defined(MSWIN)
    .def_val={ .type = kOptValTypeString, .data.string = { .data = ">%s 2>&1", .size = sizeof(">%s 2>&1") - 1 } },
#else
    .def_val={ .type = kOptValTypeString, .data.string = { .data = ">", .size = sizeof(">") - 1 } },
#endif
  },
  [248]={
    .fullname="shellslash",
    .shortname="ssl",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
#if defined(BACKSLASH_IN_FILENAME)
    .var=&p_ssl,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_shellslash,
#else
    .var=&options[248].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
#endif
#if defined(MSWIN)
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
#else
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
#endif
  },
  [249]={
    .fullname="shelltemp",
    .shortname="stmp",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_stmp,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [250]={
    .fullname="shellxescape",
    .shortname="sxe",
    .flags=0|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_sxe,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [251]={
    .fullname="shellxquote",
    .shortname="sxq",
    .flags=0|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_sxq,
    .immutable=false,
    .indir=PV_NONE,
#if defined(MSWIN)
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "\"", .size = sizeof("\"") - 1 } },
#else
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
#endif
  },
  [252]={
    .fullname="shiftround",
    .shortname="sr",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_sr,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [253]={
    .fullname="shiftwidth",
    .shortname="sw",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_sw,
    .immutable=false,
    .indir=OPT_BUF(BV_SW),
    .opt_did_set_cb=did_set_shiftwidth_tabstop,
    .def_val={ .type = kOptValTypeNumber, .data.number = 8L },
  },
  [254]={
    .fullname="shortmess",
    .shortname="shm",
    .flags=0|kOptFlagFlagList,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_shm,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_shortmess,
    .opt_expand_cb=expand_set_shortmess,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "ltToOCF", .size = sizeof("ltToOCF") - 1 } },
  },
  [255]={
    .fullname="showbreak",
    .shortname="sbr",
    .flags=0|kOptFlagRedrAll,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_sbr,
    .immutable=false,
    .indir=OPT_BOTH(OPT_WIN(WV_SBR)),
    .opt_did_set_cb=did_set_showbreak,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [256]={
    .fullname="showcmd",
    .shortname="sc",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_sc,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [257]={
    .fullname="showcmdloc",
    .shortname="sloc",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_sloc,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_showcmdloc,
    .opt_expand_cb=expand_set_showcmdloc,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "last", .size = sizeof("last") - 1 } },
  },
  [258]={
    .fullname="showfulltag",
    .shortname="sft",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_sft,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [259]={
    .fullname="showmatch",
    .shortname="sm",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_sm,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [260]={
    .fullname="showmode",
    .shortname="smd",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_smd,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [261]={
    .fullname="showtabline",
    .shortname="stal",
    .flags=0|kOptFlagRedrAll|kOptFlagUIOption,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_stal,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_showtabline,
    .def_val={ .type = kOptValTypeNumber, .data.number = 1L },
  },
  [262]={
    .fullname="sidescroll",
    .shortname="ss",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_ss,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 1L },
  },
  [263]={
    .fullname="sidescrolloff",
    .shortname="siso",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_siso,
    .immutable=false,
    .indir=OPT_BOTH(OPT_WIN(WV_SISO)),
    .def_val={ .type = kOptValTypeNumber, .data.number = 0L },
  },
  [264]={
    .fullname="signcolumn",
    .shortname="scl",
    .flags=0|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_SCL),
    .opt_did_set_cb=did_set_signcolumn,
    .opt_expand_cb=expand_set_signcolumn,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "auto", .size = sizeof("auto") - 1 } },
  },
  [265]={
    .fullname="smartcase",
    .shortname="scs",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_scs,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [266]={
    .fullname="smartindent",
    .shortname="si",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_si,
    .immutable=false,
    .indir=OPT_BUF(BV_SI),
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [267]={
    .fullname="smarttab",
    .shortname="sta",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_sta,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [268]={
    .fullname="smoothscroll",
    .shortname="sms",
    .flags=0|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_SMS),
    .opt_did_set_cb=did_set_smoothscroll,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [269]={
    .fullname="softtabstop",
    .shortname="sts",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_sts,
    .immutable=false,
    .indir=OPT_BUF(BV_STS),
    .def_val={ .type = kOptValTypeNumber, .data.number = 0L },
  },
  [270]={
    .fullname="spell",
    .flags=0|kOptFlagRedrWin|kOptFlagHLOnly,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_SPELL),
    .opt_did_set_cb=did_set_spell,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [271]={
    .fullname="spellcapcheck",
    .shortname="spc",
    .flags=0|kOptFlagRedrBuf|kOptFlagHLOnly,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_spc,
    .immutable=false,
    .indir=OPT_BUF(BV_SPC),
    .opt_did_set_cb=did_set_spellcapcheck,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "[.?!]\\_[\\])'\"\\t ]\\+", .size = sizeof("[.?!]\\_[\\])'\"\\t ]\\+") - 1 } },
  },
  [272]={
    .fullname="spellfile",
    .shortname="spf",
    .flags=0|kOptFlagOneComma|kOptFlagExpand|kOptFlagSecure|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_spf,
    .immutable=false,
    .indir=OPT_BUF(BV_SPF),
    .opt_did_set_cb=did_set_spellfile,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [273]={
    .fullname="spelllang",
    .shortname="spl",
    .flags=0|kOptFlagOneComma|kOptFlagRedrBuf|kOptFlagHLOnly|kOptFlagExpand|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_spl,
    .immutable=false,
    .indir=OPT_BUF(BV_SPL),
    .opt_did_set_cb=did_set_spelllang,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "en", .size = sizeof("en") - 1 } },
  },
  [274]={
    .fullname="spelloptions",
    .shortname="spo",
    .flags=0|kOptFlagOneComma|kOptFlagRedrBuf|kOptFlagHLOnly|kOptFlagSecure|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_spo,
    .immutable=false,
    .indir=OPT_BUF(BV_SPO),
    .opt_did_set_cb=did_set_spelloptions,
    .opt_expand_cb=expand_set_spelloptions,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [275]={
    .fullname="spellsuggest",
    .shortname="sps",
    .flags=0|kOptFlagOneComma|kOptFlagExpand|kOptFlagSecure|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_sps,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_spellsuggest,
    .opt_expand_cb=expand_set_spellsuggest,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "best", .size = sizeof("best") - 1 } },
  },
  [276]={
    .fullname="splitbelow",
    .shortname="sb",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_sb,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [277]={
    .fullname="splitkeep",
    .shortname="spk",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_spk,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_splitkeep,
    .opt_expand_cb=expand_set_splitkeep,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "cursor", .size = sizeof("cursor") - 1 } },
  },
  [278]={
    .fullname="splitright",
    .shortname="spr",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_spr,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [279]={
    .fullname="startofline",
    .shortname="sol",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_sol,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [280]={
    .fullname="statuscolumn",
    .shortname="stc",
    .flags=0|kOptFlagRedrWin|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_STC),
    .opt_did_set_cb=did_set_statuscolumn,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [281]={
    .fullname="statusline",
    .shortname="stl",
    .flags=0|kOptFlagRedrStat|kOptFlagMLE,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_stl,
    .immutable=false,
    .indir=OPT_BOTH(OPT_WIN(WV_STL)),
    .opt_did_set_cb=did_set_statusline,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [282]={
    .fullname="suffixes",
    .shortname="su",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_su,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = ".bak,~,.o,.h,.info,.swp,.obj", .size = sizeof(".bak,~,.o,.h,.info,.swp,.obj") - 1 } },
  },
  [283]={
    .fullname="suffixesadd",
    .shortname="sua",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_sua,
    .immutable=false,
    .indir=OPT_BUF(BV_SUA),
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [284]={
    .fullname="swapfile",
    .shortname="swf",
    .flags=0|kOptFlagRedrStat,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_swf,
    .immutable=false,
    .indir=OPT_BUF(BV_SWF),
    .opt_did_set_cb=did_set_swapfile,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [285]={
    .fullname="switchbuf",
    .shortname="swb",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_swb,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_switchbuf,
    .opt_expand_cb=expand_set_switchbuf,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "uselast", .size = sizeof("uselast") - 1 } },
  },
  [286]={
    .fullname="synmaxcol",
    .shortname="smc",
    .flags=0|kOptFlagRedrBuf,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_smc,
    .immutable=false,
    .indir=OPT_BUF(BV_SMC),
    .def_val={ .type = kOptValTypeNumber, .data.number = 3000L },
  },
  [287]={
    .fullname="syntax",
    .shortname="syn",
    .flags=0|kOptFlagNoGlob|kOptFlagNFname,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_syn,
    .immutable=false,
    .indir=OPT_BUF(BV_SYN),
    .opt_did_set_cb=did_set_filetype_or_syntax,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [288]={
    .fullname="tabclose",
    .shortname="tcl",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_tcl,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_tabclose,
    .opt_expand_cb=expand_set_tabclose,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [289]={
    .fullname="tabline",
    .shortname="tal",
    .flags=0|kOptFlagRedrTabl|kOptFlagMLE,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_tal,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_tabline,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [290]={
    .fullname="tabpagemax",
    .shortname="tpm",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_tpm,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 50L },
  },
  [291]={
    .fullname="tabstop",
    .shortname="ts",
    .flags=0|kOptFlagRedrBuf,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_ts,
    .immutable=false,
    .indir=OPT_BUF(BV_TS),
    .opt_did_set_cb=did_set_shiftwidth_tabstop,
    .def_val={ .type = kOptValTypeNumber, .data.number = 8L },
  },
  [292]={
    .fullname="tagbsearch",
    .shortname="tbs",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_tbs,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [293]={
    .fullname="tagcase",
    .shortname="tc",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_tc,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_TC)),
    .opt_did_set_cb=did_set_tagcase,
    .opt_expand_cb=expand_set_tagcase,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "followic", .size = sizeof("followic") - 1 } },
  },
  [294]={
    .fullname="tagfunc",
    .shortname="tfu",
    .flags=0|kOptFlagSecure|kOptFlagFunc,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_tfu,
    .immutable=false,
    .indir=OPT_BUF(BV_TFU),
    .opt_did_set_cb=did_set_tagfunc,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [295]={
    .fullname="taglength",
    .shortname="tl",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_tl,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 0L },
  },
  [296]={
    .fullname="tagrelative",
    .shortname="tr",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_tr,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [297]={
    .fullname="tags",
    .shortname="tag",
    .flags=0|kOptFlagOneComma|kOptFlagExpand|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_tags,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_TAGS)),
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "./tags;,tags", .size = sizeof("./tags;,tags") - 1 } },
  },
  [298]={
    .fullname="tagstack",
    .shortname="tgst",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_tgst,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [299]={
    .fullname="termbidi",
    .shortname="tbidi",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_tbidi,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [300]={
    .fullname="termencoding",
    .shortname="tenc",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&options[300].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [301]={
    .fullname="termguicolors",
    .shortname="tgc",
    .flags=0|kOptFlagUIOption,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_tgc,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [302]={
    .fullname="termpastefilter",
    .shortname="tpf",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_tpf,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_termpastefilter,
    .opt_expand_cb=expand_set_termpastefilter,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "BS,HT,ESC,DEL", .size = sizeof("BS,HT,ESC,DEL") - 1 } },
  },
  [303]={
    .fullname="termsync",
    .flags=0|kOptFlagUIOption,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_termsync,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [304]={
    .fullname="terse",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&options[304].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [305]={
    .fullname="textwidth",
    .shortname="tw",
    .flags=0|kOptFlagRedrBuf|kOptFlagHLOnly,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_tw,
    .immutable=false,
    .indir=OPT_BUF(BV_TW),
    .opt_did_set_cb=did_set_textwidth,
    .def_val={ .type = kOptValTypeNumber, .data.number = 0L },
  },
  [306]={
    .fullname="thesaurus",
    .shortname="tsr",
    .flags=0|kOptFlagOneComma|kOptFlagExpand|kOptFlagNDname|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_tsr,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_TSR)),
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [307]={
    .fullname="thesaurusfunc",
    .shortname="tsrfu",
    .flags=0|kOptFlagSecure|kOptFlagFunc,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_tsrfu,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_TSRFU)),
    .opt_did_set_cb=did_set_thesaurusfunc,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [308]={
    .fullname="tildeop",
    .shortname="top",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_to,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [309]={
    .fullname="timeout",
    .shortname="to",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_timeout,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [310]={
    .fullname="timeoutlen",
    .shortname="tm",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_tm,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 1000L },
  },
  [311]={
    .fullname="title",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_title,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_title_icon,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [312]={
    .fullname="titlelen",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_titlelen,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_titlelen,
    .def_val={ .type = kOptValTypeNumber, .data.number = 85L },
  },
  [313]={
    .fullname="titleold",
    .flags=0|kOptFlagNoMkrc|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_titleold,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [314]={
    .fullname="titlestring",
    .flags=0|kOptFlagMLE,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_titlestring,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_titlestring,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [315]={
    .fullname="ttimeout",
    .flags=0|kOptFlagUIOption,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_ttimeout,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [316]={
    .fullname="ttimeoutlen",
    .shortname="ttm",
    .flags=0|kOptFlagUIOption,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_ttm,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 50L },
  },
  [317]={
    .fullname="ttyfast",
    .shortname="tf",
    .flags=0|kOptFlagNoMkrc,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&options[317].def_val.data,
    .immutable=true,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [318]={
    .fullname="undodir",
    .shortname="udir",
    .flags=0|kOptFlagOneComma|kOptFlagExpand|kOptFlagNoDefExp|kOptFlagSecure|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_udir,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [319]={
    .fullname="undofile",
    .shortname="udf",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_udf,
    .immutable=false,
    .indir=OPT_BUF(BV_UDF),
    .opt_did_set_cb=did_set_undofile,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [320]={
    .fullname="undolevels",
    .shortname="ul",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_ul,
    .immutable=false,
    .indir=OPT_BOTH(OPT_BUF(BV_UL)),
    .opt_did_set_cb=did_set_undolevels,
    .def_val={ .type = kOptValTypeNumber, .data.number = 1000L },
  },
  [321]={
    .fullname="undoreload",
    .shortname="ur",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_ur,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 10000L },
  },
  [322]={
    .fullname="updatecount",
    .shortname="uc",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_uc,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_updatecount,
    .def_val={ .type = kOptValTypeNumber, .data.number = 200L },
  },
  [323]={
    .fullname="updatetime",
    .shortname="ut",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_ut,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 4000L },
  },
  [324]={
    .fullname="varsofttabstop",
    .shortname="vsts",
    .flags=0|kOptFlagComma,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_vsts,
    .immutable=false,
    .indir=OPT_BUF(BV_VSTS),
    .opt_did_set_cb=did_set_varsofttabstop,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [325]={
    .fullname="vartabstop",
    .shortname="vts",
    .flags=0|kOptFlagComma|kOptFlagRedrBuf,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_vts,
    .immutable=false,
    .indir=OPT_BUF(BV_VTS),
    .opt_did_set_cb=did_set_vartabstop,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [326]={
    .fullname="verbose",
    .shortname="vbs",
    .flags=0|kOptFlagUIOption,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_verbose,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 0L },
  },
  [327]={
    .fullname="verbosefile",
    .shortname="vfile",
    .flags=0|kOptFlagExpand|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_vfile,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_verbosefile,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [328]={
    .fullname="viewdir",
    .shortname="vdir",
    .flags=0|kOptFlagExpand|kOptFlagNoDefExp|kOptFlagSecure,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_vdir,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [329]={
    .fullname="viewoptions",
    .shortname="vop",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_vop,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_viewoptions,
    .opt_expand_cb=expand_set_sessionoptions,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "folds,cursor,curdir", .size = sizeof("folds,cursor,curdir") - 1 } },
  },
  [330]={
    .fullname="virtualedit",
    .shortname="ve",
    .flags=0|kOptFlagOneComma|kOptFlagCurswant|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_ve,
    .immutable=false,
    .indir=OPT_BOTH(OPT_WIN(WV_VE)),
    .opt_did_set_cb=did_set_virtualedit,
    .opt_expand_cb=expand_set_virtualedit,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [331]={
    .fullname="visualbell",
    .shortname="vb",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_vb,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [332]={
    .fullname="warn",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_warn,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [333]={
    .fullname="whichwrap",
    .shortname="ww",
    .flags=0|kOptFlagComma|kOptFlagFlagList,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_ww,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_whichwrap,
    .opt_expand_cb=expand_set_whichwrap,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "b,s", .size = sizeof("b,s") - 1 } },
  },
  [334]={
    .fullname="wildchar",
    .shortname="wc",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_wc,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_wildchar,
    .def_val={ .type = kOptValTypeNumber, .data.number = TAB },
  },
  [335]={
    .fullname="wildcharm",
    .shortname="wcm",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_wcm,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_wildchar,
    .def_val={ .type = kOptValTypeNumber, .data.number = 0L },
  },
  [336]={
    .fullname="wildignore",
    .shortname="wig",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_wig,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [337]={
    .fullname="wildignorecase",
    .shortname="wic",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_wic,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [338]={
    .fullname="wildmenu",
    .shortname="wmnu",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_wmnu,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [339]={
    .fullname="wildmode",
    .shortname="wim",
    .flags=0|kOptFlagOneComma|kOptFlagColon,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_wim,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_wildmode,
    .opt_expand_cb=expand_set_wildmode,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "full", .size = sizeof("full") - 1 } },
  },
  [340]={
    .fullname="wildoptions",
    .shortname="wop",
    .flags=0|kOptFlagOneComma|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_wop,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_wildoptions,
    .opt_expand_cb=expand_set_wildoptions,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "pum,tagfile", .size = sizeof("pum,tagfile") - 1 } },
  },
  [341]={
    .fullname="winaltkeys",
    .shortname="wak",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_wak,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_winaltkeys,
    .opt_expand_cb=expand_set_winaltkeys,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "menu", .size = sizeof("menu") - 1 } },
  },
  [342]={
    .fullname="winbar",
    .shortname="wbr",
    .flags=0|kOptFlagRedrStat|kOptFlagMLE,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=&p_wbr,
    .immutable=false,
    .indir=OPT_BOTH(OPT_WIN(WV_WBR)),
    .opt_did_set_cb=did_set_winbar,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [343]={
    .fullname="winblend",
    .shortname="winbl",
    .flags=0|kOptFlagRedrWin|kOptFlagHLOnly,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_WINBL),
    .opt_did_set_cb=did_set_winblend,
    .def_val={ .type = kOptValTypeNumber, .data.number = 0L },
  },
  [344]={
    .fullname="window",
    .shortname="wi",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_window,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_window,
    .def_val={ .type = kOptValTypeNumber, .data.number = 0L },
  },
  [345]={
    .fullname="winfixbuf",
    .shortname="wfb",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_WFB),
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [346]={
    .fullname="winfixheight",
    .shortname="wfh",
    .flags=0|kOptFlagRedrStat,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_WFH),
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [347]={
    .fullname="winfixwidth",
    .shortname="wfw",
    .flags=0|kOptFlagRedrStat,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_WFW),
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [348]={
    .fullname="winheight",
    .shortname="wh",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_wh,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_winheight,
    .def_val={ .type = kOptValTypeNumber, .data.number = 1L },
  },
  [349]={
    .fullname="winhighlight",
    .shortname="winhl",
    .flags=0|kOptFlagOneComma|kOptFlagColon|kOptFlagRedrWin|kOptFlagHLOnly|kOptFlagNoDup,
    .type_flags=0 | (1 << kOptValTypeString),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_WINHL),
    .opt_did_set_cb=did_set_winhighlight,
    .opt_expand_cb=expand_set_winhighlight,
    .def_val={ .type = kOptValTypeString, .data.string = { .data = "", .size = sizeof("") - 1 } },
  },
  [350]={
    .fullname="winminheight",
    .shortname="wmh",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_wmh,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_winminheight,
    .def_val={ .type = kOptValTypeNumber, .data.number = 1L },
  },
  [351]={
    .fullname="winminwidth",
    .shortname="wmw",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_wmw,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_winminwidth,
    .def_val={ .type = kOptValTypeNumber, .data.number = 1L },
  },
  [352]={
    .fullname="winwidth",
    .shortname="wiw",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_wiw,
    .immutable=false,
    .indir=PV_NONE,
    .opt_did_set_cb=did_set_winwidth,
    .def_val={ .type = kOptValTypeNumber, .data.number = 20L },
  },
  [353]={
    .fullname="wrap",
    .flags=0|kOptFlagRedrWin,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=VAR_WIN,
    .immutable=false,
    .indir=OPT_WIN(WV_WRAP),
    .opt_did_set_cb=did_set_wrap,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [354]={
    .fullname="wrapmargin",
    .shortname="wm",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_wm,
    .immutable=false,
    .indir=OPT_BUF(BV_WM),
    .def_val={ .type = kOptValTypeNumber, .data.number = 0L },
  },
  [355]={
    .fullname="wrapscan",
    .shortname="ws",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_ws,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [356]={
    .fullname="write",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_write,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [357]={
    .fullname="writeany",
    .shortname="wa",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_wa,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = false },
  },
  [358]={
    .fullname="writebackup",
    .shortname="wb",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeBoolean),
    .var=&p_wb,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeBoolean, .data.boolean = true },
  },
  [359]={
    .fullname="writedelay",
    .shortname="wd",
    .flags=0,
    .type_flags=0 | (1 << kOptValTypeNumber),
    .var=&p_wd,
    .immutable=false,
    .indir=PV_NONE,
    .def_val={ .type = kOptValTypeNumber, .data.number = 0L },
  },
};

#define PV_ARAB OPT_WIN(WV_ARAB)
#define PV_AI OPT_BUF(BV_AI)
#define PV_AR OPT_BOTH(OPT_BUF(BV_AR))
#define PV_BKC OPT_BOTH(OPT_BUF(BV_BKC))
#define PV_BIN OPT_BUF(BV_BIN)
#define PV_BOMB OPT_BUF(BV_BOMB)
#define PV_BRI OPT_WIN(WV_BRI)
#define PV_BRIOPT OPT_WIN(WV_BRIOPT)
#define PV_BH OPT_BUF(BV_BH)
#define PV_BL OPT_BUF(BV_BL)
#define PV_BT OPT_BUF(BV_BT)
#define PV_CHANNEL OPT_BUF(BV_CHANNEL)
#define PV_CIN OPT_BUF(BV_CIN)
#define PV_CINK OPT_BUF(BV_CINK)
#define PV_CINO OPT_BUF(BV_CINO)
#define PV_CINSD OPT_BUF(BV_CINSD)
#define PV_CINW OPT_BUF(BV_CINW)
#define PV_CC OPT_WIN(WV_CC)
#define PV_COM OPT_BUF(BV_COM)
#define PV_CMS OPT_BUF(BV_CMS)
#define PV_CPT OPT_BUF(BV_CPT)
#define PV_CFU OPT_BUF(BV_CFU)
#define PV_COT OPT_BOTH(OPT_BUF(BV_COT))
#define PV_CSL OPT_BUF(BV_CSL)
#define PV_COCU OPT_WIN(WV_COCU)
#define PV_COLE OPT_WIN(WV_COLE)
#define PV_CI OPT_BUF(BV_CI)
#define PV_CRBIND OPT_WIN(WV_CRBIND)
#define PV_CUC OPT_WIN(WV_CUC)
#define PV_CUL OPT_WIN(WV_CUL)
#define PV_CULOPT OPT_WIN(WV_CULOPT)
#define PV_DEF OPT_BOTH(OPT_BUF(BV_DEF))
#define PV_DICT OPT_BOTH(OPT_BUF(BV_DICT))
#define PV_DIFF OPT_WIN(WV_DIFF)
#define PV_EOF OPT_BUF(BV_EOF)
#define PV_EOL OPT_BUF(BV_EOL)
#define PV_EP OPT_BOTH(OPT_BUF(BV_EP))
#define PV_EFM OPT_BOTH(OPT_BUF(BV_EFM))
#define PV_ET OPT_BUF(BV_ET)
#define PV_FENC OPT_BUF(BV_FENC)
#define PV_FF OPT_BUF(BV_FF)
#define PV_FT OPT_BUF(BV_FT)
#define PV_FCS OPT_BOTH(OPT_WIN(WV_FCS))
#define PV_FFU OPT_BOTH(OPT_BUF(BV_FFU))
#define PV_FIXEOL OPT_BUF(BV_FIXEOL)
#define PV_FDC OPT_WIN(WV_FDC)
#define PV_FEN OPT_WIN(WV_FEN)
#define PV_FDE OPT_WIN(WV_FDE)
#define PV_FDI OPT_WIN(WV_FDI)
#define PV_FDL OPT_WIN(WV_FDL)
#define PV_FMR OPT_WIN(WV_FMR)
#define PV_FDM OPT_WIN(WV_FDM)
#define PV_FML OPT_WIN(WV_FML)
#define PV_FDN OPT_WIN(WV_FDN)
#define PV_FDT OPT_WIN(WV_FDT)
#define PV_FEX OPT_BUF(BV_FEX)
#define PV_FLP OPT_BUF(BV_FLP)
#define PV_FO OPT_BUF(BV_FO)
#define PV_FP OPT_BOTH(OPT_BUF(BV_FP))
#define PV_GP OPT_BOTH(OPT_BUF(BV_GP))
#define PV_IMI OPT_BUF(BV_IMI)
#define PV_IMS OPT_BUF(BV_IMS)
#define PV_INC OPT_BOTH(OPT_BUF(BV_INC))
#define PV_INEX OPT_BUF(BV_INEX)
#define PV_INDE OPT_BUF(BV_INDE)
#define PV_INDK OPT_BUF(BV_INDK)
#define PV_INF OPT_BUF(BV_INF)
#define PV_ISK OPT_BUF(BV_ISK)
#define PV_KMAP OPT_BUF(BV_KMAP)
#define PV_KP OPT_BOTH(OPT_BUF(BV_KP))
#define PV_LBR OPT_WIN(WV_LBR)
#define PV_LISP OPT_BUF(BV_LISP)
#define PV_LOP OPT_BUF(BV_LOP)
#define PV_LW OPT_BOTH(OPT_BUF(BV_LW))
#define PV_LIST OPT_WIN(WV_LIST)
#define PV_LCS OPT_BOTH(OPT_WIN(WV_LCS))
#define PV_MENC OPT_BOTH(OPT_BUF(BV_MENC))
#define PV_MP OPT_BOTH(OPT_BUF(BV_MP))
#define PV_MPS OPT_BUF(BV_MPS)
#define PV_ML OPT_BUF(BV_ML)
#define PV_MA OPT_BUF(BV_MA)
#define PV_MOD OPT_BUF(BV_MOD)
#define PV_NF OPT_BUF(BV_NF)
#define PV_NU OPT_WIN(WV_NU)
#define PV_NUW OPT_WIN(WV_NUW)
#define PV_OFU OPT_BUF(BV_OFU)
#define PV_PATH OPT_BOTH(OPT_BUF(BV_PATH))
#define PV_PI OPT_BUF(BV_PI)
#define PV_PVW OPT_WIN(WV_PVW)
#define PV_QE OPT_BUF(BV_QE)
#define PV_RO OPT_BUF(BV_RO)
#define PV_RNU OPT_WIN(WV_RNU)
#define PV_RL OPT_WIN(WV_RL)
#define PV_RLC OPT_WIN(WV_RLC)
#define PV_SCROLL OPT_WIN(WV_SCROLL)
#define PV_SCBK OPT_BUF(BV_SCBK)
#define PV_SCBIND OPT_WIN(WV_SCBIND)
#define PV_SO OPT_BOTH(OPT_WIN(WV_SO))
#define PV_SW OPT_BUF(BV_SW)
#define PV_SBR OPT_BOTH(OPT_WIN(WV_SBR))
#define PV_SISO OPT_BOTH(OPT_WIN(WV_SISO))
#define PV_SCL OPT_WIN(WV_SCL)
#define PV_SI OPT_BUF(BV_SI)
#define PV_SMS OPT_WIN(WV_SMS)
#define PV_STS OPT_BUF(BV_STS)
#define PV_SPELL OPT_WIN(WV_SPELL)
#define PV_SPC OPT_BUF(BV_SPC)
#define PV_SPF OPT_BUF(BV_SPF)
#define PV_SPL OPT_BUF(BV_SPL)
#define PV_SPO OPT_BUF(BV_SPO)
#define PV_STC OPT_WIN(WV_STC)
#define PV_STL OPT_BOTH(OPT_WIN(WV_STL))
#define PV_SUA OPT_BUF(BV_SUA)
#define PV_SWF OPT_BUF(BV_SWF)
#define PV_SMC OPT_BUF(BV_SMC)
#define PV_SYN OPT_BUF(BV_SYN)
#define PV_TS OPT_BUF(BV_TS)
#define PV_TC OPT_BOTH(OPT_BUF(BV_TC))
#define PV_TFU OPT_BUF(BV_TFU)
#define PV_TAGS OPT_BOTH(OPT_BUF(BV_TAGS))
#define PV_TW OPT_BUF(BV_TW)
#define PV_TSR OPT_BOTH(OPT_BUF(BV_TSR))
#define PV_TSRFU OPT_BOTH(OPT_BUF(BV_TSRFU))
#define PV_UDF OPT_BUF(BV_UDF)
#define PV_UL OPT_BOTH(OPT_BUF(BV_UL))
#define PV_VSTS OPT_BUF(BV_VSTS)
#define PV_VTS OPT_BUF(BV_VTS)
#define PV_VE OPT_BOTH(OPT_WIN(WV_VE))
#define PV_WBR OPT_BOTH(OPT_WIN(WV_WBR))
#define PV_WINBL OPT_WIN(WV_WINBL)
#define PV_WFB OPT_WIN(WV_WFB)
#define PV_WFH OPT_WIN(WV_WFH)
#define PV_WFW OPT_WIN(WV_WFW)
#define PV_WINHL OPT_WIN(WV_WINHL)
#define PV_WRAP OPT_WIN(WV_WRAP)
#define PV_WM OPT_BUF(BV_WM)
